@@ -12,7 +12,7 @@ extern crate regex;
 extern crate serde;
 
 pub use framework_detector::FrameworkDetector;
-pub use framework_detector::Frameworks;
+pub use framework_detector::FrameworkContainer;
 pub use framework_detector::Framework;
 pub use framework_detector::SourceFile;
 
@@ -20,3 +20,4 @@ pub mod dependency;
 pub mod facet;
 pub mod framework_detector;
 pub mod lang;
+pub mod frameworks;
